@@ -148,7 +148,7 @@ use Carp;
 use JSON::MaybeXS;
 use Types::Standard qw[ArrayRef HashRef InstanceOf Str];
 
-our $VERSION = '0.0.10';
+our $VERSION = '0.0.11';
 
 requires qw[json_ld_type json_ld_fields];
 
@@ -170,7 +170,7 @@ has context => (
 );
 
 sub _build_context {
-  return 'http://schema.org';
+  return 'http://schema.org/';
 }
 
 sub json_ld_data {
